@@ -1,7 +1,7 @@
 #!/bin/sh
 
 version=$2
-orig_tgz=$(basename $3)
+orig_tgz=almond_${version}.orig.tar.gz
 orig_txz=almond_${version}+dfsg.orig.tar.xz
 newdir=$(echo $orig_tgz | sed -e 's/.orig.tar.gz//' -e 's/_/-/')+dfsg
 
@@ -19,6 +19,7 @@ if [ -L $orig_tgz ] ; then rm $(readlink $orig_tgz); fi
 rm $orig_tgz
 
 tar cJf $orig_txz $newdir
+rm -rf $newdir
 
-echo "Created ../$orig_txz and ../$newdir"
+echo "Created ../$orig_txz"
 
